@@ -1,10 +1,9 @@
 #' Set the Transaction Isolation Level for a Connection
 #'
-#' @param levels One or more of \Sexpr[stage=render, results=rd]{odbc:::choices_rd(names(odbc:::transactionLevels()))}.
+#' @param levels One or more of `r odbc:::choices_rd(names(odbc:::transactionLevels()))`.
 #' @inheritParams DBI::dbDisconnect
-#' @seealso \url{https://docs.microsoft.com/en-us/sql/odbc/reference/develop-app/setting-the-transaction-isolation-level}
+#' @seealso <https://docs.microsoft.com/en-us/sql/odbc/reference/develop-app/setting-the-transaction-isolation-level>
 #' @export
-#' @noMd
 #' @examples
 #' \dontrun{
 #' # Can use spaces or underscores in between words.
@@ -14,6 +13,7 @@
 #' odbcSetTransactionIsolationLevel(con, "SQL_TXN_READ_UNCOMMITTED")
 #' }
 odbcSetTransactionIsolationLevel <- function(conn, levels) {
+  arg_match(levels, values = names(transactionLevels()), multiple = TRUE)
   # Convert to lowercase, spaces to underscores, remove sql_txn prefix
   levels <- tolower(levels)
   levels <- gsub(" ", "_", levels)
