@@ -4,24 +4,25 @@
 
 namespace odbc {
 
-void odbc_connection::cancel_current_result(bool quiet) {
+void odbc_connection::cancel_current_result() {
   if (current_result_ == nullptr) {
     return;
   }
 
-  if (!quiet) {
-    Rcpp::warning("Cancelling previous query");
-  }
   current_result_->statement()->cancel();
   current_result_ = nullptr;
 }
 
+bool odbc_connection::has_result() const {
+  return current_result_ != nullptr;
+}
+
 void odbc_connection::set_current_result(odbc_result* r) {
   if (r == current_result_) {
     return;
   }
 
-  cancel_current_result(r == nullptr);
+  cancel_current_result();
   current_result_ = r;
 }
 
@@ -32,11 +33,13 @@ odbc_connection::odbc_connection(
     std::string encoding,
     bigint_map_t bigint_mapping,
     long timeout,
-    Rcpp::Nullable<Rcpp::List> const& r_attributes_)
+    Rcpp::Nullable<Rcpp::List> const& r_attributes,
+    bool const& interruptible_execution)
     : current_result_(nullptr),
       timezone_out_str_(timezone_out),
       encoding_(encoding),
-      bigint_mapping_(bigint_mapping) {
+      bigint_mapping_(bigint_mapping),
+      interruptible_execution_(interruptible_execution) {
 
   if (!cctz::load_time_zone(timezone, &timezone_)) {
     Rcpp::stop("Error loading time zone (%s)", timezone);
@@ -52,10 +55,11 @@ odbc_connection::odbc_connection(
     std::list< nanodbc::connection::attribute > attributes;
     std::list< std::shared_ptr< void > > buffer_context;
     utils::prepare_connection_attributes(
-        timeout, r_attributes_, attributes, buffer_context );
+        timeout, r_attributes, attributes, buffer_context );
     c_ = std::make_shared<nanodbc::connection>(connection_string, attributes);
   } catch (const nanodbc::database_error& e) {
-    throw Rcpp::exception(e.what(), FALSE);
+    Iconv encoder(this->encoding(), "UTF-8");
+    utils::raise_error(odbc_error(e, "", encoder));
   }
 }
 
